[Piuparts-commits] rev 519 - in trunk: . debian piupartslib

Holger Levsen holger at alioth.debian.org
Thu Oct 8 13:29:27 UTC 2009


Author: holger
Date: 2009-10-08 13:29:27 +0000 (Thu, 08 Oct 2009)
New Revision: 519

Modified:
   trunk/TODO
   trunk/debian/changelog
   trunk/piuparts-report.py
   trunk/piupartslib/packagesdb.py
Log:
make a graph of the last two quarters, not one

Modified: trunk/TODO
===================================================================
--- trunk/TODO	2009-10-08 13:21:14 UTC (rev 518)
+++ trunk/TODO	2009-10-08 13:29:27 UTC (rev 519)
@@ -9,8 +9,6 @@
 
 for 0.37 and 0.38 (split this list):
 
-- piuparts-report mail should include list of failed logs of the day
-
 - PackagesDB: get rid of 50% of unique()
 
 - remove configfile option "mirror" and use the mirror from "packages-url".
@@ -107,7 +105,8 @@
 - support for extra-packages-url (for volatile, security, etc)
 
 - not sure if it's a sensible thing to to, but provide a way to turn off debugging
-  output for piuparts.py
+  output for piuparts.py - see http://docs.python.org/library/logging.html
+- commandline-switches for all programms 
 
 - piuparts can't currently test postfix, since installing postfix removes
   exim and removing postfix would require re-installing exim, and that

Modified: trunk/debian/changelog
===================================================================
--- trunk/debian/changelog	2009-10-08 13:21:14 UTC (rev 518)
+++ trunk/debian/changelog	2009-10-08 13:29:27 UTC (rev 519)
@@ -1,7 +1,7 @@
 piuparts (0.37) UNRELEASED; urgency=low
 
-  * piuparts-report.py: report packages failing due to insserv errors.
-    (Closes: #546540) 
+  * piuparts-report.py: report packages with update-rc.d warnings and those 
+    failing due to insserv errors. (Closes: #546540) 
   * Fix typo in NEWS.Debian, thanks to Justin Rye for spotting it. 
     (Closes: #547439)
 

Modified: trunk/piuparts-report.py
===================================================================
--- trunk/piupartslib/packagesdb.py	2009-10-08 13:21:14 UTC (rev 518)
+++ trunk/piupartslib/packagesdb.py	2009-10-08 13:29:27 UTC (rev 519)
@@ -353,6 +353,10 @@
             return state
 
         deps = self._get_recursive_dependencies(package, break_circles=False)
+        # ignore those packages.
+        for pkg in ['perl', 'perl-modules', 'openjdk-6-jre-headless', 'openjdk-6-jre-lib', 'ca-certificates-java', 'rhino', 'libjline-java', 'java-gcj-compat-headless', 'gij', 'gcj-jre-headless', 'fortune-mod', 'fortunes-min']:
+            if pkg in deps:
+                deps.remove(pkg)
         if package["Package"] in deps:
             return "circular-dependency"
             




More information about the Piuparts-commits mailing list
--- trunk/piuparts-report.py	2009-10-08 13:21:14 UTC (rev 518)
+++ trunk/piuparts-report.py	2009-10-08 13:29:27 UTC (rev 519)
@@ -806,14 +806,14 @@
         pngfile = os.path.join(self._output_directory, "states.png")
         r('t <- (read.table("'+countsfile+'",sep=",",header=1,row.names=1))')
         r('cname <- c("date",rep(colnames(t)))')
-        # here we define how many days we wants stats for
-        r('v <- t[(nrow(t)-90):nrow(t),0:12]')
+        # here we define how many days we wants stats for (163=half a year)
+        r('v <- t[(nrow(t)-163):nrow(t),0:12]')
         # thanks to http://tango.freedesktop.org/Generic_Icon_Theme_Guidelines for those nice colors
         r('palette(c("#4e9a06", "#ef2929", "#73d216", "#d3d7cf", "#5c3566", "#c4a000", "#fce94f", "#a40000", "#888a85", "#2e3436", "#8ae234",  "#729fcf","#204a87"))')
         r('bitmap(file="'+pngfile+'",type="png16m",width=16,height=9,pointsize=10,res=100)')
-        r('barplot(t(v),col = 1:13, main="Packages per state in '+self._config.section+' (past quarter)", xlab="", ylab="Number of packages",space=0.1,border=0)')
+        r('barplot(t(v),col = 1:13, main="Packages per state in '+self._config.section+' (past half year)", xlab="", ylab="Number of packages",space=0.1,border=0)')
         r('legend(x="bottom",legend=colnames(t), ncol=2,fill=1:13,xjust=0.5,yjust=0,bty="n")')
-        return "<tr class=\"normalrow\"> <td class=\"contentcell2\" colspan=\"3\"><a href=\"%s\"><img src=\"/%s/%s\" height=\"450\" width=\"800\" alt=\"Package states in the last quarter\"></a></td></tr>\n" % ("states.png", self._config.section, "states.png")
+        return "<tr class=\"normalrow\"> <td class=\"contentcell2\" colspan=\"3\"><a href=\"%s\"><img src=\"/%s/%s\" height=\"450\" width=\"800\" alt=\"Package states in the last half year\"></a></td></tr>\n" % ("states.png", self._config.section, "states.png")
 
     def create_and_link_to_analysises(self,state):
         link="<ul>"

Modified: trunk/piupartslib/packagesdb.py
===================================================================